@@ -2,6 +2,7 @@
 
 import sys
 
+from typing import List
 from typing import Optional
 from typing import TextIO
 
@@ -41,6 +42,9 @@ class CommentNode(ast.Node):
     ) -> Optional[bool]:
         return False
 
+    def children(self) -> List[ast.ChildNode]:
+        return []
+
 
 class CommentTag(Tag):
     """The built-in "comment" tag."""
