@@ -90,7 +90,7 @@ from liquid.token import TOKEN_GE
 from liquid.token import reverse_operators
 from liquid.token import Token
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from liquid import Environment
 
 
@@ -428,7 +428,7 @@ def parse_unchained_identifier(
     return ident
 
 
-# NOTE: These names are missleading. The args and options in question can apply to any
+# NOTE: These names are misleading. The args and options in question can apply to any
 # iterable in a loop expression, not just ranges.
 
 RangeArg = Union[
