@@ -1,6 +1,7 @@
 """Test miscellaneous filter functions."""
 # pylint: disable=too-many-public-methods,too-many-lines,missing-class-docstring
 import datetime
+import platform
 import unittest
 
 from functools import partial
@@ -360,6 +361,19 @@ class MiscFilterTestCase(unittest.TestCase):
                 kwargs={},
                 expect=datetime.datetime.now().strftime("%Y"),
             ),
+            # Case(
+            #     description="negative timestamp integer",
+            #     val=-1152098955,
+            #     args=["%Y"],
+            #     kwargs={},
+            #     expect="1933",
+            # ),
         ]
 
         self._test(date, test_cases)
+
+    @unittest.skipUnless(platform.system() == "Windows", "windows specific test")
+    def test_parse_timestamp_on_windows(self):
+        """Test that we can handle parsing timestamps on windows."""
+        result = date(-1152098955, "%Y", environment=self.env)
+        self.assertEqual(result, "-1152098955")
